@@ -11,10 +11,10 @@
 #include "exprwnd.h"
 #include "pgmsettings.h"
 #include "programconfig.h"
-#include <ntqregexp.h>
-#include <ntqfileinfo.h>
-#include <ntqlistbox.h>
-#include <ntqstringlist.h>
+#include <tqregexp.h>
+#include <tqfileinfo.h>
+#include <tqlistbox.h>
+#include <tqstringlist.h>
 #include <tdeapplication.h>
 #include <tdeconfig.h>
 #include <tdelocale.h>			/* i18n */
@@ -1451,8 +1451,7 @@ bool KDebugger::handlePrintDeref(CmdQueueItem* cmd, const char* output)
 void KDebugger::handleBacktrace(const char* output)
 {
     // reduce flicker
-    m_btWindow.setAutoUpdate(false);
-
+    m_btWindow.setUpdatesEnabled(false);
     m_btWindow.clear();
 
     std::list<StackFrame> stack;
@@ -1475,8 +1474,7 @@ void KDebugger::handleBacktrace(const char* output)
 		  TQString().setNum(frm->lineNo+1) + ")");
 	}
     }
-
-    m_btWindow.setAutoUpdate(true);
+    m_btWindow.setUpdatesEnabled(true);
     m_btWindow.repaint();
 }
 
